pub struct SliceSharedOp { /* private fields */ }Expand description
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
cube_slice_shared_offset | ATTR_KEY_CUBE_SLICE_SHARED_OFFSET | IndexAttr |
cube_slice_shared_value_ty | ATTR_KEY_CUBE_SLICE_SHARED_VALUE_TY | TypeAttr |
Implementations
Get a Ref to the value of the attribute named cube_slice_shared_offset.
The Ref is a borrow of the containing Operation object.
Set the value of the attribute named cube_slice_shared_offset.
Get a Ref to the value of the attribute named cube_slice_shared_value_ty.
The Ref is a borrow of the containing Operation object.
Set the value of the attribute named cube_slice_shared_value_ty.
pub fn new( ctx: &mut Context, result_ty: TypeHandle, block: Value, offset: impl Into<IndexAttr>, value_ty: impl Into<TypeAttr>, ) -> Self
pub fn block(&self, ctx: &Context) -> Value
pub fn block_as_use(&self, ctx: &Context) -> Use<Value>
pub fn offset<'a>(&self, ctx: &'a Context) -> Ref<'a, IndexAttr>
pub fn value_ty<'a>(&self, ctx: &'a Context) -> Ref<'a, TypeAttr>
pub fn set_offset(&self, ctx: &Context, value: impl Into<IndexAttr>)
pub fn set_value_ty(&self, ctx: &Context, value: impl Into<TypeAttr>)