pub struct BasicBlock {
pub phi_nodes: Rc<RefCell<Vec<PhiInstruction>>>,
pub ops: Rc<RefCell<StableVec<Instruction>>>,
pub control_flow: Rc<RefCell<ControlFlow>>,
/* private fields */
}Expand description
A basic block of instructions interrupted by control flow. Phi nodes are assumed to come before any instructions. See https://en.wikipedia.org/wiki/Basic_block
Fields
phi_nodes: Rc<RefCell<Vec<PhiInstruction>>>The phi nodes that are required to be generated at the start of this block.
ops: Rc<RefCell<StableVec<Instruction>>>A stable list of operations performed in this block.
control_flow: Rc<RefCell<ControlFlow>>The control flow that terminates this block.