Function

Struct Function 

pub struct Function {
    pub explicit_params: Vec<Value>,
    pub implicit_params: Vec<Value>,
    pub memories: HashMap<Id, MemoryBlock>,
    pub graph: StableDiGraph<BasicBlock, u32>,
    pub root: NodeIndex,
    pub ret: NodeIndex,
    pub return_value: Option<Value>,
    /* private fields */
}

Fields

explicit_params: Vec<Value>

Explicit parameters passed to the function, i.e. the inputs to a closure

implicit_params: Vec<Value>

Implicit parameters passed to the function, i.e. kernel args, closure captures

memories: HashMap<Id, MemoryBlock>graph: StableDiGraph<BasicBlock, u32>root: NodeIndexret: NodeIndex

The single return block

return_value: Option<Value>

The return value, if any

Implementations

Source

impl Function

pub fn analysis<A: Analysis + Any>(&mut self, state: &GlobalState) -> Rc<A>

Fetch an analysis if cached, or run it if not.

pub fn invalidate_analysis<A: Analysis + Any>(&self)

Invalidate an analysis by removing it from the cache. The analysis is rerun when requested again.

pub fn invalidate_structure(&self)

Invalidate all analyses that rely on the structure of the control flow graph.

Source

impl Function

pub fn local_variable_id(&self, value: &Value) -> Option<Id>

Gets the id of the variable if it’s a destructurable Local and not atomic, None otherwise.

pub fn local_memory_id(&self, value: &Value) -> Option<Id>

Gets the id of the variable if it’s a Local memory and not atomic, None otherwise.

Unlike Function::local_variable_id, this includes non-destructurable locals such as arrays, so it can be used by backends that allocate and free those memories.

Source

impl Function

pub fn visit_all( &mut self, state: &GlobalState, visit_read: impl FnMut(&mut Self, &mut Value) + Clone, visit_write: impl FnMut(&mut Self, &mut Value) + Clone, )

Visit all operations in the program with the specified read and write visitors.

Source

impl Function

pub fn dot_viz(&self) -> String

Source

impl Function

pub fn visit_out( &mut self, val: &mut Option<Value>, visit_write: impl FnMut(&mut Self, &mut Value), )

pub fn visit_instruction_memory_writes( &mut self, state: &GlobalState, inst: &Instruction, visit_write: impl FnMut(&mut Self, &MemoryBlock), )

Visit an instruction with only a write visitor. Visits both out and any pointer writes.

pub fn visit_instruction_memory_reads( &mut self, state: &GlobalState, inst: &Instruction, visit_read: impl FnMut(&mut Self, &MemoryBlock), )

pub fn visit_instruction( &mut self, state: &GlobalState, inst: &mut Instruction, visit_read: impl FnMut(&mut Self, &mut Value), visit_write: impl FnMut(&mut Self, &mut Value), )

Visit an operation with a set of read and write visitors. Each visitor will be called with each read or written to variable.

pub fn visit_operation( &mut self, state: &GlobalState, op: &mut Operation, visit_read: impl FnMut(&mut Self, &mut Value), )

Visit an operation with a set of read and write visitors. Each visitor will be called with each read or written to variable.

pub fn visit_control_flow( &mut self, op: &mut ControlFlow, visit_read: impl FnMut(&mut Self, &mut Value), )

Visit a control flow finisher with a set of read and write visitors. Each visitor will be called with each read or written to variable.

Source

impl Function

pub fn place_phi_nodes(&mut self, state: &GlobalState)

Places a phi node for each live variable at each frontier

pub fn insert_phi(&mut self, block: NodeIndex, id: Id, item: Type)

Insert a phi node for variable id at block

pub fn destructurable_local_memories(&self) -> HashMap<Id, MemoryBlock>

Returns all pointers to local stack space that are destructurable

Source

impl Function

pub fn parse_scope(&mut self, state: &GlobalState, scope: Scope) -> bool

Recursively parse a scope into the graph

pub fn predecessors(&self, block: NodeIndex) -> Vec<NodeIndex>

List of predecessor IDs of the block

pub fn successors(&self, block: NodeIndex) -> Vec<NodeIndex>

List of successor IDs of the block

pub fn breadth_first_dominators(&self) -> Vec<NodeIndex>

Return the breadth-first list of nodes along the dominator tree. This is useful for generating the blocks in a human-readable-ish order that follows the Vulkan spec (dominators before dominated).

pub fn block(&self, block: NodeIndex) -> &BasicBlock

Reference to the BasicBlock with ID block

pub fn block_mut(&mut self, block: NodeIndex) -> &mut BasicBlock

Reference to the BasicBlock with ID block

pub fn is_unreachable(&self, block: NodeIndex) -> bool

pub fn node_ids(&self) -> Vec<NodeIndex>

A set of node indices for all blocks in the program

pub fn all_params(&self) -> impl Iterator<Item = Value>

pub fn create_local_mut(&mut self, state: &GlobalState, value_ty: Type) -> Value