MemoryBlock

Struct MemoryBlock 

pub struct MemoryBlock {
    pub address_space: AddressSpace,
    pub value_ty: Type,
    pub alignment: usize,
    pub root_ptr: Value,
}

Fields

address_space: AddressSpacevalue_ty: Typealignment: usizeroot_ptr: Value

The root pointer value returned from the allocation or passed into the kernel. All other pointers into the same value are derived from this.

Implementations

Source

impl MemoryBlock

pub fn size(&self) -> usize

The byte size of this shared memory