MemoryLiveness

Struct MemoryLiveness 

pub struct MemoryLiveness { /* private fields */ }
Block level liveness over all non-atomic local memories, including non-destructurable ones such as arrays.

[Liveness] only tracks destructurable locals (those that get promoted to SSA registers and phi nodes). Backends that keep local memory as actual allocations and need to free it when it dies (e.g. the CPU backend) must also track non-destructurable locals, which this analysis does.

Implementations

Source

impl MemoryLiveness

pub fn empty(func: &Function) -> Self

pub fn at_block(&self, block: NodeIndex) -> &HashSet<Id>

pub fn is_dead(&self, node: NodeIndex, var: Id) -> bool