pub struct Optimizer {
pub main: Function,
pub global_state: GlobalState,
}Expand description
An optimizer that applies various analyses and optimization passes to the IR.
Fields
main: Functionglobal_state: GlobalStateThe overall program state
Implementations
Sourceimpl Optimizer
impl Optimizer
Sourcepub fn new(
expand: Scope,
cube_dim: CubeDim,
transformers: Vec<Rc<dyn IrTransformer>>,
visitors: Vec<Box<dyn InstructionVisitor>>,
processors: Vec<Box<dyn Processor>>,
) -> Self
pub fn new( expand: Scope, cube_dim: CubeDim, transformers: Vec<Rc<dyn IrTransformer>>, visitors: Vec<Box<dyn InstructionVisitor>>, processors: Vec<Box<dyn Processor>>, ) -> Self
Create a new optimizer with the scope, CubeDim and execution mode passed into the compiler.
Parses the scope and runs several optimization and analysis loops.
Create a new optimizer with the scope, CubeDim and execution mode passed into the compiler.
Parses the scope and runs several optimization and analysis loops.